<?php 
$lan = array(
  'SaveChanges' => 'Enregistrer les modifications',
  'NameNotEmpty' => 'Vous devez choisir un nom:',
  'NameNotUnique' => 'Ce nom est d&eacute;j&agrave; pris',
  'ExistingAttr' => 'Attributs existants:',
  'NoAttrYet' => 'Aucun Attribut n&rsquo;a encore &eacute;t&eacute; d&eacute;fini<br/>',
  'Attribute' => 'Attribut:',
  'Delete' => 'Supprimer',
  'Name' => 'Nom:',
  'Type' => 'Type:',
  'DValue' => 'Valeur par d&eacute;faut:',
  'OrderListing' => 'Ordre d&rsquo;apparition:',
  'IsAttrRequired' => 'Cet attribut est-il obligatoire?:',
  'AddAttr' => 'Ajouter un nouvel Attribut:',
);
?>